package com.palnet.board.app.jh.controller;

import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.palnet.board.app.jh.dto.JunheePageDto;
import com.palnet.board.app.jh.dto.JunheeRequestBoard;
import com.palnet.board.app.jh.dto.JunheeResponseBoard;
import com.palnet.board.app.jh.dto.JunheeResponsePrevNext;
import com.palnet.board.app.jh.service.JunheeBoardService;

import lombok.RequiredArgsConstructor;

@RequiredArgsConstructor
@RestController
@RequestMapping("/api/jh/board")
public class JunheeBoardRestController {

	final static Logger log = LoggerFactory.getLogger(JunheeBoardRestController.class);

	private final JunheeBoardService BoardService;

	@GetMapping("/detailView/{id}")
	public ResponseEntity<JunheeResponseBoard> detailView(@PathVariable String id) throws Exception {
		JunheeResponseBoard responseBoard = BoardService.detailView(id);

		return ResponseEntity.status(HttpStatus.OK).body(responseBoard);
	}

	@PostMapping("/write")
	public ResponseEntity<Integer> boardWrite(JunheeRequestBoard requestBoard) throws Exception {
		int result = BoardService.boardWrite(requestBoard);

		return ResponseEntity.status(HttpStatus.OK).body(result);
	}

	@DeleteMapping("/delete/{id}")
	public ResponseEntity<Integer> boardDelete(@PathVariable String id) throws Exception {
		int result = BoardService.boardDelete(id);

		return ResponseEntity.status(HttpStatus.OK).body(result);
	}

	@PutMapping("/modify")
	public ResponseEntity<Integer> boardModify(JunheeRequestBoard requestBoard) throws Exception {
		int result = BoardService.boardModify(requestBoard);

		return ResponseEntity.status(HttpStatus.OK).body(result);
	}

	@GetMapping("/boardMaxId")
	public ResponseEntity<Integer> boardMaxId() throws Exception {
		int boardMaxId = BoardService.boardMaxId();

		return ResponseEntity.status(HttpStatus.OK).body(boardMaxId);
	}	
	
	@GetMapping("/page/{pageNum}")
	public ResponseEntity<List<JunheeResponseBoard>> selectListPage(@PathVariable int pageNum) throws Exception {
		List<JunheeResponseBoard> responseBoard = BoardService.selectListPage(pageNum);
		
		return ResponseEntity.status(HttpStatus.OK).body(responseBoard);
	}
	
	@GetMapping("/pageHelp")
	public ResponseEntity<JunheePageDto> pageHelp() throws Exception {
		JunheePageDto pageDto = BoardService.pageHelp();
		
		return ResponseEntity.status(HttpStatus.OK).body(pageDto);
	}
	
	@GetMapping("/boardPrevNext/{id}")
	public ResponseEntity<List<JunheeResponsePrevNext>> boardPrevNext(@PathVariable int id) throws Exception {
		List<JunheeResponsePrevNext> response = BoardService.boardPrevNext(id);
		
		return ResponseEntity.status(HttpStatus.OK).body(response);
	}

}
