package com.palnet.board.app.jh.service;

import java.util.ArrayList;
import java.util.List;

import org.springframework.stereotype.Service;

import com.palnet.board.app.jh.dto.JunheeBoardDto;
import com.palnet.board.app.jh.dto.JunheePageDto;
import com.palnet.board.app.jh.dto.JunheeRequestBoard;
import com.palnet.board.app.jh.dto.JunheeResponseBoard;
import com.palnet.board.app.jh.dto.JunheeResponsePrevNext;
import com.palnet.board.app.jh.mapper.JunheeBoardMapper;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;


@RequiredArgsConstructor
@Service
@Slf4j
public class JunheeBoardServiceImpl implements JunheeBoardService{
	
	private final JunheeBoardMapper BoardMapper;

	
	/* 글 상세보기 */
	@Override
	public JunheeResponseBoard detailView(String id) throws Exception {
		JunheeBoardDto boardDto = BoardMapper.detailView(id);
		
		JunheeResponseBoard responseBoard = new JunheeResponseBoard();
		responseBoard.setId(boardDto.getId());
		responseBoard.setPassword(boardDto.getPassword());
		responseBoard.setTitle(boardDto.getTitle());
		responseBoard.setContent(boardDto.getContent());
		responseBoard.setRegUser(boardDto.getRegUser());
		responseBoard.setRegDtm(boardDto.getRegDtm());
		responseBoard.setUpdUser(boardDto.getUpdUser());
		
		return responseBoard;
	}
	
	/* 글 작성하기 */
	@Override
	public int boardWrite(JunheeRequestBoard requestBoard) throws Exception {
		int result = BoardMapper.boardWrite(requestBoard);
		return result;
	}

	/* 글 삭제하기 */
	@Override
	public int boardDelete(String id) throws Exception {
		int result = BoardMapper.boardDelete(id);
		return result;
	}
	
	/* 글 수정하기 */
	@Override
	public int boardModify(JunheeRequestBoard requestBoard) throws Exception {
		int result = BoardMapper.boardModify(requestBoard);
		return result;
	}
	
	/* 글 번호 자동부여 */
	@Override
	public int boardMaxId() throws Exception{
		int boardId = BoardMapper.boardMaxId();
		return boardId;
	}
	
	
	/* 쿼리문으로 페이징하기 */
	@Override
	public List<JunheeResponseBoard> selectListPage(int pageNum) throws Exception {
		
		int endNum = 7;
		int startNum = (pageNum * endNum) - endNum;
		
		List<JunheeBoardDto> boardDto = BoardMapper.selectListPage(startNum, endNum);
		List<JunheeResponseBoard> boardList = new ArrayList<JunheeResponseBoard>();
		
		for(JunheeBoardDto board : boardDto) {
			JunheeResponseBoard responseBoard = new JunheeResponseBoard();
			
			responseBoard.setId(board.getId());
			responseBoard.setTitle(board.getTitle());
			responseBoard.setRegUser(board.getRegUser());
			responseBoard.setRegDtm(board.getRegDtm());
			responseBoard.setUpdUser(board.getUpdUser());
	  		
	  		boardList.add(responseBoard);
		}
		
		return boardList;
	}

	/* 전체 게시글 수 & 마지막 페이지 숫자  */
	@Override
	public JunheePageDto pageHelp() throws Exception {
		int boardCount = BoardMapper.boardCount();
		int boardViewCount = 7;	//화면에 보여지는 게시글 수
		int maxPageNum = 0;
		
		if((boardCount % boardViewCount) == 0) {
			maxPageNum = boardCount/boardViewCount;
		} else {
			maxPageNum = (boardCount/boardViewCount) + 1;
		}

		JunheePageDto pageDto = new JunheePageDto();
		pageDto.setBoardCount(boardCount);
		pageDto.setMaxPageNum(maxPageNum);
		
		return pageDto;
	}
	
	/* 이전글 / 다음글 id, title */
	@Override
	public List<JunheeResponsePrevNext> boardPrevNext(int id) throws Exception {
		List<JunheeResponsePrevNext> boardPrevNext = BoardMapper.boardPrevNext(id);
		List<JunheeResponsePrevNext> boardList = new ArrayList<JunheeResponsePrevNext>();
		
		for(JunheeResponsePrevNext board : boardPrevNext) {
			JunheeResponsePrevNext responseBoard = new JunheeResponsePrevNext();
			
			responseBoard.setId(board.getId());
			responseBoard.setTitle(board.getTitle());
	  		
	  		boardList.add(responseBoard);
		}
		
		return boardList;
	}
	
    
}
