package com.palnet.board.app.sample.controller;

import com.palnet.board.app.sample.dto.SampleBoardDto;
import com.palnet.board.app.sample.service.SampleBoardService;
import lombok.RequiredArgsConstructor;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;


@RequiredArgsConstructor
@RestController
@RequestMapping("/api/sample/board")
public class SampleBoardRestController {

    final static Logger log = LoggerFactory.getLogger(SampleBoardRestController.class);

    private final SampleBoardService sampleBoardService;

    // 글 목록 조회
    @GetMapping("/list")
    public List<SampleBoardDto> list(){
        return sampleBoardService.list();
    }

    // 글 상세 조회
    @GetMapping("/detail/{id}")
    public SampleBoardDto detail(@PathVariable Integer id){
        return sampleBoardService.detail(id);
    }

    // 글 등록
    @PostMapping("/create")
    public Map create(@RequestBody SampleBoardDto rq){
        Map<String, String> res = new HashMap<>();
        try {
            int cnt = sampleBoardService.create(rq);
            if(cnt > 0){
                res.put("result", "success");
            } else {
                res.put("result", "fail");
            }
        } catch (Exception e){
            log.error("{}", e);
            res.put("result", "fail");
        }
        return res;
    }


    // 글 수정
    @PutMapping("/update")
    public Map update(@RequestBody SampleBoardDto rq){
        Map<String, String> res = new HashMap<>();
        try {
            int cnt = sampleBoardService.update(rq);
            if(cnt > 0){
                res.put("result", "success");
            } else {
                res.put("result", "fail");
            }
        } catch (Exception e){
            log.error("{}", e);
            res.put("result", "fail");
        }
        return res;
    }


    // 글 삭제
    @DeleteMapping("/delete/{id}")
    public Map delete(@PathVariable Integer id){
        Map<String, String> res = new HashMap<>();
        try {
            int cnt = sampleBoardService.delete(id);
            if(cnt > 0){
                res.put("result", "success");
            } else {
                res.put("result", "fail");
            }
        } catch (Exception e){
            log.error("{}", e);
            res.put("result", "fail");
        }
        return res;
    }


}
